( function( $ ) {
	$( document ).ready( function() {
		var requests = CB.Activity.Requests,
			dom = CB.Activity.DOM;

		// Hide all activity comment forms
		$( 'form.ac-form' ).hide();

		// Hide excess comments.
		dom.hideComments();

		// this is not the right way to do it but we are doing it temporarily.
		// enable rtMedia comment support.
		rtmRestoreCommentingState();

		$( document ).on( 'click:activity:comment:showall', function( evt, $target ) {
			/* Showing hidden comments - pause for half a second */
			$target.parent().addClass( 'loading' );

			setTimeout( function() {
				$target.parent().parent().children( 'li' ).fadeIn( 200, function() {
					$target.parent().remove();
				} );
			}, 600 );
		} );

		// Comments.
		$( document ).on( 'click:activity:reply', function( evt, target, activityID, commentID, type ) {
			// Comment / comment reply links
			var $form = $( '#ac-form-' + activityID );

			$form.css( 'display', 'none' );
			$form.removeClass( 'root' );
			// hide all comment forms.
			$( '.ac-form' ).hide();

			// Hide any error messages
			$form.find( '.error' ).hide();

			if ( type !== 'comment' ) {
				$( '#acomment-' + commentID ).append( $form );
			} else {
				$( '#activity-' + activityID + ' .activity-comments' ).append( $form );
			}

			if ( $form.parent().hasClass( 'activity-comments' ) ) {
				$form.addClass( 'root' );
			}

			$form.slideDown( 200 );
			$.scrollTo( $form, 500, {
				offset: -100,
				easing: 'swing'
			} );
			$form.find( '.ac-input' ).focus();
			$form.trigger( 'activity:reply:form:visible', [ $form, activityID ] );
			return false;
		} );

		// Comment reply cancel, hide form.
		$( document ).on( 'click:activity:comment:reply:cancel', function( evt, $target ) {
			// Canceling an activity comment
			$target.closest( '.ac-form' ).slideUp( 200 );
			return false;
		} );

		$( document ).on( 'click:activity:comment:submit', function( evt, target, form, activityID, commentID, content, nonce, akNonce ) {
			var commentData = {
				activity_id: activityID,
				comment_id: commentID,
				content: content,
				_wpnonce: nonce,
				nonce2: akNonce
			};


			// Hide any error messages.
			form.find( '.error' ).hide();
			target.addClass( 'loading' ).prop( 'disabled', true );
			form.addClass( 'loading' );//.prop('disabled', true);

			CB.Activity.CommentFilter.fire( commentData );

			requests.postComment( commentData ).done( function( response ) {
				var $activityComments, theComment, $activity, newCount, $showAllAnchor;
				target.removeClass( 'loading' );
				form.removeClass( 'loading' );

				// Check for errors and append if found.
				if ( ! response.success ) {
					CB.DOM.Notices.append( form, response.data.message, 'error' );
					form.find( '.site-feedback-message' ).hide().fadeIn( 200 );
					return;
				}

				$activityComments = form.parent();
				form.fadeOut( 200, function() {
					if ( 0 === $activityComments.children( 'ul' ).length ) {
						if ( $activityComments.hasClass( 'activity-comments' ) ) {
							$activityComments.prepend( '<ul></ul>' );
						} else {
							$activityComments.append( '<ul></ul>' );
						}
					}

					/* Preceding whitespace breaks output with jQuery 1.9.0 */
					theComment = $.trim( response.data.content );

					$activityComments.children( 'ul' ).append( $( theComment ).hide().fadeIn( 200 ) );
					form.find( '.ac-input' ).val( '' );
					$activityComments.parent().addClass( 'has-comments' );
				} );

				form.find( 'textarea' ).val( '' );

				// Increase the "Reply (X)" button count
				$activity = $( '#activity-' + activityID );
				newCount = Number( $activity.find( '.acomment-reply span' ).html() ) + 1;
				$activity.find( '.acomment-reply span' ).html( newCount );

				// Increment the 'Show all x comments' string, if present
				$showAllAnchor = $activityComments.parents( '.activity-comments' ).find( '.show-all-comments a' );
				if ( $showAllAnchor ) {
					$showAllAnchor.html( CBBPSettings.showXComments.replace( '%d', newCount ) );
				}

				target.prop( 'disabled', false );

			} );

			return false;
		} );

		$( document ).on( 'click:activity:comment:delete', function( evt, target, comment, commentID, nonce ) {
			var $form, $activity;
			if ( target.hasClass( 'loading' ) ) {
				return;
			}

			$form = comment.parents( '.activity-comments' ).children( 'form' );
			$activity = comment.closest( '.activity-item' );

			target.addClass( 'loading' );

			// Remove any error messages
			$activity.find( '.activity-comments ul .error' ).remove();

			// Reset the form position
			comment.parents( '.activity-comments' ).append( $form );

			requests.deleteComment( { id: commentID, _wpnonce: nonce } ).done( function( response ) {
				var children, childCount, countSpan, newCount, showAllAnchor;
				//Check for errors and append if found.
				if ( ! response.success ) {
					CB.DOM.Notices.prepend( comment, response.data.message, 'error' );
					comment.find( '.error' ).hide().fadeIn( 200 );
					return;
				}
				// if we are here, the request succeeded.
				children = $( '#acomment-' + response.data.id + ' ul' ).children( 'li' );
				childCount = 0;

				$( children ).each( function() {
					if ( ! $( this ).is( ':hidden' ) ) {
						childCount++;
					}
				} );
				comment.fadeOut( 200, function() {
					comment.remove();
				} );

				// Decrease the "Reply (X)" button count
				countSpan = $activity.find( '.acomment-reply span' );
				newCount = countSpan.html() - ( 1 + childCount );
				countSpan.html( newCount );

				// Change the 'Show all x comments' text
				showAllAnchor = comment.parents( '.activity-comments' ).find( '.show-all-comments a' );
				if ( showAllAnchor ) {
					showAllAnchor.html( CBBPSettings.showXComments.replace( '%d', newCount ) );
				}

				//If that was the last comment for the item, remove the has-comments class to clean up the styling
				if ( 0 === newCount ) {
					$activity.removeClass( 'has-comments' );
				}
			} );

			return false;
		} );

		$( document ).on( 'click:activity:comment:spam', function( evt, target, comment, commentID, nonce ) {
			var activity;
			if ( target.hasClass( 'loading' ) ) {
				return;
			}

			target.addClass( 'loading' );

			activity = comment.closest( '.activity-item' );
			// Remove any error messages
			activity.find( '.error' ).remove();

			// Reset the form position
			comment.parents( '.activity-comments' ).append( comment.parents( '.activity-comments' ).children( 'form' ) );

			requests.spamComment( { id: commentID, _wpnonce: nonce } ).done( function( response ) {
				var children, childCount;
				// Check for errors and append if found.
				if ( ! response.success ) {
					CB.DOM.Notices.prepend( comment, response.data.message, 'error' );
					comment.find( '.error' ).hide().fadeIn( 200 );
					return;
				}

				children = $( '#' + comment.attr( 'id' ) + ' ul' ).children( 'li' );
				childCount = 0;

				$( children ).each( function() {
					if ( ! $( this ).is( ':hidden' ) ) {
						childCount++;
					}
				} );
				comment.fadeOut( 200 );

				// Decrease the "Reply (X)" button count
				$( '#' + activity.attr( 'id' ) + ' .acomment-reply span' ).html( $( '#' + activity.attr( 'id' ) + ' a.acomment-reply span' ).html() - ( 1 + childCount ) );
			} );
		} );
	} );

	// A copy of rtmedia_activity_comment_js_add_media_id() from rtMedia 4.6 with updated action name and
	// we are using activity_id instead of form id.
	function rtmRestoreCommentingState(){

		if( typeof rtmedia_comment_media_remove_hidden_media_id === "undefined" ) {
			return;
		}

		jQuery.ajaxPrefilter( function( options, originalOptions, jqXHR ) {
			// Modify options, control originalOptions, store jqXHR, etc
			try {
				if ( originalOptions.data == null || typeof ( originalOptions.data ) == 'undefined' || typeof ( originalOptions.data.action ) == 'undefined' ) {
					return true;
				}
			} catch ( e ) {
				return true;
			}

			if ( originalOptions.data.action == 'activity_post_comment' ) {
				widget_id = 'activity-'+originalOptions.data.activity_id

				var rtmedia_disable_media = 1;
				if( typeof rtmedia_disable_media_in_commented_media != 'undefined' ){
					rtmedia_disable_media = rtmedia_disable_media_in_commented_media;
				}

				var temp = jQuery( '.'+comment_media_wrapper+widget_id ).find( 'input[name="rtMedia_attached_files[]"]' ).val();

				if( typeof temp == 'undefined' ){
					temp = 0;
				}

				if( typeof temp == '' ){
					temp = 0;
				}
				options.data += '&rtMedia_attached_files[]=' + temp;
				options.data += '&rtmedia_disable_media_in_commented_media=' + rtmedia_disable_media;

				activity_attachemnt_ids = temp;

				var orignalSuccess = originalOptions.success;

				options.beforeSend = function() {
					if ( originalOptions.data.action == 'activity_post_comment' ) {

						if( rtmedia_disable_media == 1 ){
							if( originalOptions.data.activity_id != originalOptions.data.comment_id && temp > 0 ){
								jQuery( '.'+comment_media_wrapper+widget_id ).append('<div id="message" class="error bp-ajax-message" style="display: block;"><p> ' + rtmedia_disable_media_in_commented_media_text + ' </p></div>')
								jQuery( '.'+comment_media_wrapper+widget_id ).removeAttr( 'disabled' );

								rtmedia_comment_media_input_button( widget_id, false );

								rtmedia_disable_comment_textbox( widget_id, false );

								return false;
							}
						}
					}
				};
				options.success = function( response ) {
					if ( orignalSuccess && 'function' === typeof orignalSuccess ) {
						orignalSuccess( response );
					}
					if ( response[0] + response[1] == '-1' ) {
						//Error

					} else {
						if ( originalOptions.data.action == 'activity_post_comment' ) {

							rtmedia_comment_media_remove_hidden_media_id( widget_id );

							rtmedia_comment_media_textbox_val( widget_id, false );

							rtmedia_comment_media_input_button( widget_id, false );

							setTimeout( function() {
								rtmedia_apply_popup_to_media();

								rtmedia_reset_video_and_audio();

							}, 500 );

							rtMediaHook.call( 'rtmedia_js_after_comment_added', [ ] );
						}
					}

				};
				options.error = function() {
					if ( originalOptions.data.action == 'activity_post_comment' ) {

						rtmedia_comment_media_remove_hidden_media_id( widget_id );

						rtmedia_comment_media_textbox_val( widget_id, false );

						rtmedia_comment_media_input_button( widget_id, false );
					}
				};
			}
		} );
	}
}( jQuery ) );
