<?php
/**
 * Community Builder Comments List/Form template.
 *
 * @package    Community_Builder
 * @subpackage Template
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

// if the post is password protected, do not show comment by default.
if ( post_password_required() ) {
	return;
}
?>

<section id="comments" class="article-comments clearfix">

	<?php if ( have_comments() ) : ?>

		<h2 id="comments-title" class="comments-title">
			<?php
			$text = _n( 'One Comment', '%1$s Comments', get_comments_number(), 'community-builder' );

			printf( $text, '<span class="comment-count">'. number_format_i18n( get_comments_number() ) .'</span>'  );
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>

				<nav id="comment-nav-above" class="clearfix navigation comment-navigation comment-navigation-top">

					<h1 class="accessibly-hidden"><?php _e( 'Comment navigation', 'community-builder' ); ?></h1>

					<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'community-builder' ) ); ?></div>

					<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'community-builder' ) ); ?></div>
				</nav>
		<?php endif; ?>

		<ul class="comment-list">
			<?php
			wp_list_comments(
				array(
					'style'       => 'ul',
					'short_ping'  => true,
					'avatar_size' => 50,
					'type'        => 'comment',
				)
			);
			?>
		</ul><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>

				<div id="comment-nav-below" class="navigation comment-navigation comment-navigation-bottom">

					<h2 class="accessibly-hidden"><?php _e( 'Comment navigation', 'community-builder' ); ?></h2>

					<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'community-builder' ) ); ?></div>

					<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'community-builder' ) ); ?></div>
				</div>

		<?php endif; ?>
	<?php endif; // end for have_comments(). ?>

	<?php
	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
		?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'community-builder' ); ?></p>
	<?php endif; ?>

	<?php if ( comments_open() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<?php

		$commenter = wp_get_current_commenter();
		$user      = wp_get_current_user();
		// $user_identity = $user->exists() ? $user->display_name : '';
		$format = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';

		$req      = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );
		$html_req = ( $req ? " required='required'" : '' );
		$html5    = 'html5' === $format;

		?>
		<?php
		comment_form(
			array(
				'class_form'    => 'standard-form comment-form',
				'fields'        => array(
					'author' => '<p class="comment-form-author"><label for="author">' .
								'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . $html_req . '  placeholder ="' . ( $req ? __( 'Your Name*', 'community-builder' ) : __( 'Your Name', 'community-builder' ) ) . '"/></label></p>',
					'email'  => '<p class="comment-form-email"><label for="email">' .
								'<input id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-describedby="email-notes"' . $aria_req . $html_req . '  placeholder="' . ( $req ? __( 'Your Email*', 'community-builder' ) : __( 'Your Email', 'community-builder' ) ) . '"/></label></p>',
					'url'    => '<p class="comment-form-url"><label for="url">' .
								'<input id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" placeholder="' . __( 'Website', 'community-builder' ) . '"/></label></p>',
				),
				'comment_field' => '<p class="comment-form-comment"><textarea name="comment" id="comment" cols="60" rows="5" aria-required="true"></textarea></p>',

			)
		);
		?>
	<?php endif; ?>

	<?php
	$trackbacks     = get_comments( array( 'type' => 'trackback' ) );
	$num_trackbacks = count( $trackbacks );
	if ( ! empty( $trackbacks ) ) :
			?>
			<div id="trackbacks" class="article-trackbacks clearfix">
				<h3 class="trackback-title"><?php
					/* translators: %d: trackback count */
                    printf( _n( '%d trackback', '%d trackbacks', $num_trackbacks, 'community-builder' ), number_format_i18n( $num_trackbacks ) ) ?>
                </h3>

				<ul id="trackback-list" class="trackback-list">

					<?php foreach ( (array) $trackbacks as $trackback ) : ?>

						<li>
							<strong><?php echo get_comment_author_link( $trackback->comment_ID ); ?></strong>
							<em><?php _e( 'on', 'community-builder'); ?> <?php echo get_comment_date( '', $trackback->comment_ID ); ?></em>
						</li>

					<?php endforeach; ?>
				</ul>

			</div>
	<?php endif; ?>

</section><!-- #comments -->
