<?php
/**
 * Typography Control(Not loaded or used, see typography-responsive).
 *
 * @package    Community_Builder
 * @subpackage Customizer\Controls
 * @copyright  Copyright (c) 2018, BuddyDev
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     BuddyDev
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Typography control.
 */
class CB_Customize_Control_Typography extends WP_Customize_Control {

	/**
	 * Control type.
	 *
	 * @var string
	 */
	public $type = 'typography';

	/**
	 * Enqueue control related scripts/styles.
	 */
	public function enqueue() {

		$url_base = CB_THEME_URL . '/includes/customizer/';

		wp_enqueue_script(
			'cb-typography-control',
			$url_base . 'controls/typography/typography.js',
			array(
				'cb-customize-controls',
				'cb-selectize',
			),
			CB_THEME_VERSION,
			true
		);
	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 */
	public function to_json() {

		parent::to_json();

		if ( isset( $this->default ) ) {
			$this->json['default'] = $this->default;
		} else {
			$this->json['default'] = $this->setting->default;
		}

		$this->json['value']         = $this->value();
		$this->json['choices']       = $this->choices;
		$this->json['link']          = $this->get_link();
		$this->json['id']            = $this->id;
		$this->json['l10n']          = self::get_strings();
		$defaults                    = array(
			'font-family'    => false,
			'font-size'      => false,
			'variant'        => false,
			'line-height'    => false,
			'letter-spacing' => false,
			'color'          => false,
			'hover-color'    => false,
			'text-align'     => false,
		);
		$this->json['default']       = wp_parse_args( $this->json['default'], $defaults );
		$this->json['show_variants'] = true;
		$this->json['show_subsets']  = true;
	}

	/**
	 * An Underscore (JS) template for this control's content (but not its container).
	 *
	 * Class variables for this control class are available in the `data` JS object;
	 * export custom variables by overriding {@see Kirki_Customize_Control::to_json()}.
	 *
	 * @see WP_Customize_Control::print_template()
	 */
	protected function content_template() {
		?>
        <# if ( data.label ) { #>
        <span class="customize-control-title"> {{{ data.label }}}</span>
        <# } #>
        <# if ( data.description ) { #>
        <span class="description customize-control-description">{{{ data.description }}}</span>
        <# } #>


        <div class="wrapper cb-control-clearfix">

            <# if ( '' == data.value['font-family'] ) { data.value['font-family'] = data.default['font-family']; } #>
            <# if ( data.choices['fonts'] ) { data.fonts = data.choices['fonts']; } #>

            <# if ( data.default['font-family'] ) { #>
            <div class="font-family cb-control-clearfix">
                <h5>{{ data.l10n['font-family'] }}</h5>
                <select id="cb-typography-font-family-{{{ data.id }}}" placeholder="{{ data.l10n['select-font-family'] }}"></select>
            </div>
            <# if ( true === data.show_variants || false !== data.default.variant ) { #>
            <div class="variant  cb-variant-wrapper cb-control-half">
                <h5>{{ data.l10n['variant'] }}</h5>
                <select class="variant" id="cb-typography-variant-{{{ data.id }}}"></select>
            </div>
            <# } #>
            <# if ( true === data.show_subsets ) { #>
            <div class="subsets hide-on-standard-fonts cb-subsets-wrapper cb-control-half">
                <h5>{{ data.l10n['subsets'] }}</h5>
                <select class="subset" id="cb-typography-subsets-{{{ data.id }}}"></select>
            </div>
            <# } #>
            <# } #>

            <# if ( data.default['font-size'] ) { #>
            <div class="font-size cb-control-half">
                <h5>{{ data.l10n['font-size'] }}</h5>
                <div class="cb-range-slider"></div>
                <input class="cb-control-range" type="text" value="{{ data.value['font-size'] }}" min="8" max="100" step="1"/>

            </div>
            <# } #>

            <# if ( data.default['line-height'] ) { #>
            <div class="line-height cb-control-half">
                <h5>{{ data.l10n['line-height'] }}</h5>

                <div class="cb-range-slider"></div>
                <input class="cb-control-range" type="text" value="{{ data.value['line-height'] }}" min=".5" max="5" step=".1"/>
            </div>
            <# } #>

            <# if ( data.default['letter-spacing'] ) { #>
            <div class="letter-spacing cb-control-half">
                <h5>{{ data.l10n['letter-spacing'] }}</h5>
                <input type="text" value="{{ data.value['letter-spacing'] }}"/>
            </div>
            <# } #>

            <# if ( data.default['text-align'] ) { #>
            <div class="text-align cb-control-half">
                <h5>{{ data.l10n['text-align'] }}</h5>
                <input type="radio" value="inherit" name="_customize-typography-text-align-radio-{{ data.id }}" id="{{ data.id }}-text-align-inherit" <# if ( data.value['text-align'] === 'inherit' ) { #> checked="checked"<# } #> />
                <label for="{{ data.id }}-text-align-inherit">
                    <span class="dashicons dashicons-editor-removeformatting"></span>
                    <span class="screen-reader-text">{{ data.l10n['inherit'] }}</span>
                </label>

                <input type="radio" value="left" name="_customize-typography-text-align-radio-{{ data.id }}" id="{{ data.id }}-text-align-left" <# if ( data.value['text-align'] === 'left' ) { #> checked="checked"<# } #> />
                <label for="{{ data.id }}-text-align-left">
                    <span class="dashicons dashicons-editor-alignleft"></span>
                    <span class="screen-reader-text">{{ data.l10n['left'] }}</span>
                </label>

                <input type="radio" value="center" name="_customize-typography-text-align-radio-{{ data.id }}" id="{{ data.id }}-text-align-center" <# if ( data.value['text-align'] === 'center' ) { #> checked="checked"<# } #> />
                <label for="{{ data.id }}-text-align-center">
                    <span class="dashicons dashicons-editor-aligncenter"></span>
                    <span class="screen-reader-text">{{ data.l10n['center'] }}</span>
                </label>

                <input type="radio" value="right" name="_customize-typography-text-align-radio-{{ data.id }}" id="{{ data.id }}-text-align-right" <# if ( data.value['text-align'] === 'right' ) { #> checked="checked"<# } #> />
                <label for="{{ data.id }}-text-align-right">
                    <span class="dashicons dashicons-editor-alignright"></span>
                    <span class="screen-reader-text">{{ data.l10n['right'] }}</span>
                </label>

                <input type="radio" value="justify" name="_customize-typography-text-align-radio-{{ data.id }}" id="{{ data.id }}-text-align-justify" <# if ( data.value['text-align'] === 'justify' ) { #> checked="checked"<# } #> />
                <label for="{{ data.id }}-text-align-justify">
                    <span class="dashicons dashicons-editor-justify"></span>
                    <span class="screen-reader-text">{{ data.l10n['justify'] }}</span>
                </label>

            </div>
            <# } #>

            <# if ( data.default['text-transform'] ) { #>
            <div class="text-transform cb-control-half">
                <h5>{{ data.l10n['text-transform'] }}</h5>
                <select id="cb-typography-text-transform-{{{ data.id }}}">
                    <option value="none" <# if ( 'none' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['none'] }}</option>
                    <option value="capitalize" <# if ( 'capitalize' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['capitalize'] }}</option>
                    <option value="uppercase" <# if ( 'uppercase' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['uppercase'] }}</option>
                    <option value="lowercase" <# if ( 'lowercase' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['lowercase'] }}</option>
                    <option value="initial" <# if ( 'initial' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['initial'] }}</option>
                    <option value="inherit" <# if ( 'inherit' === data.value['text-transform'] ) { #>selected<# } #>>{{ data.l10n['inherit'] }}</option>
                </select>
            </div>
            <# } #>

            <# if ( data.default['color'] ) { #>
            <div class="color cb-control-half">
                <h5>{{ data.l10n['color'] }}</h5>
                <input type="text" data-palette="{{ data.palette }}" data-alpha-enabled="true" data-default-color="{{ data.default['color'] }}" value="{{ data.value['color'] }}" class="cb-color-control color-picker"/>
            </div>
            <# } #>

            <# if ( data.default['hover-color'] ) { #>
            <div class="color cb-control-half">
                <h5>{{ data.l10n['hover-color'] }}</h5>
                <input type="text" data-palette="{{ data.palette }}" data-default-color="{{ data.default['hover-color'] }}" value="{{ data.value['hover-color'] }}" class="cb-hover-color-control color-picker"/>
            </div>
            <# } #>
            <input class="typography-hidden-value" type="hidden" {{{ data.link }}}>
        </div>
		<?php
	}

	/**
	 * Render the control's content.
	 *
	 * @see WP_Customize_Control::render_content()
	 */
	protected function render_content() {
	}

	/**
     * Get localizable string.
     *
	 * @return array
	 */
	private static function get_strings() {

		$translation_strings = array(

			'inherit' => esc_attr__( 'Inherit', 'community-builder' ),

			'all'            => esc_attr__( 'All', 'community-builder' ),
			'cyrillic'       => esc_attr__( 'Cyrillic', 'community-builder' ),
			'cyrillic-ext'   => esc_attr__( 'Cyrillic Extended', 'community-builder' ),
			'devanagari'     => esc_attr__( 'Devanagari', 'community-builder' ),
			'greek'          => esc_attr__( 'Greek', 'community-builder' ),
			'greek-ext'      => esc_attr__( 'Greek Extended', 'community-builder' ),
			'khmer'          => esc_attr__( 'Khmer', 'community-builder' ),
			'latin'          => esc_attr__( 'Latin', 'community-builder' ),
			'latin-ext'      => esc_attr__( 'Latin Extended', 'community-builder' ),
			'vietnamese'     => esc_attr__( 'Vietnamese', 'community-builder' ),
			'hebrew'         => esc_attr__( 'Hebrew', 'community-builder' ),
			'arabic'         => esc_attr__( 'Arabic', 'community-builder' ),
			'bengali'        => esc_attr__( 'Bengali', 'community-builder' ),
			'gujarati'       => esc_attr__( 'Gujarati', 'community-builder' ),
			'tamil'          => esc_attr__( 'Tamil', 'community-builder' ),
			'telugu'         => esc_attr__( 'Telugu', 'community-builder' ),
			'thai'           => esc_attr__( 'Thai', 'community-builder' ),
			'serif'          => _x( 'Serif', 'font style', 'community-builder' ),
			'sans-serif'     => _x( 'Sans Serif', 'font style', 'community-builder' ),
			'monospace'      => _x( 'Monospace', 'font style', 'community-builder' ),
			'font-family'    => esc_attr__( 'Font Family', 'community-builder' ),
			'font-size'      => esc_attr__( 'Font Size(px)', 'community-builder' ),
			'font-weight'    => esc_attr__( 'Font Weight', 'community-builder' ),
			'line-height'    => esc_attr__( 'Line Height(em)', 'community-builder' ),
			'font-style'     => esc_attr__( 'Font Style', 'community-builder' ),
			'letter-spacing' => esc_attr__( 'Letter Spacing', 'community-builder' ),
			'top'            => esc_attr__( 'Top', 'community-builder' ),
			'bottom'         => esc_attr__( 'Bottom', 'community-builder' ),
			'left'           => esc_attr__( 'Left', 'community-builder' ),
			'right'          => esc_attr__( 'Right', 'community-builder' ),
			'center'         => esc_attr__( 'Center', 'community-builder' ),
			'justify'        => esc_attr__( 'Justify', 'community-builder' ),
			'color'          => esc_attr__( 'Color', 'community-builder' ),
			'hover-color'    => esc_attr__( 'Hover Color', 'community-builder' ),

			'remove'             => esc_attr__( 'Remove', 'community-builder' ),
			'select-font-family' => esc_attr__( 'Select a font-family', 'community-builder' ),
			'variant'            => esc_attr__( 'Variant', 'community-builder' ),
			'subsets'            => esc_attr__( 'Subset', 'community-builder' ),
			'size'               => esc_attr__( 'Size', 'community-builder' ),
			'height'             => esc_attr__( 'Height', 'community-builder' ),
			'spacing'            => esc_attr__( 'Spacing', 'community-builder' ),
			'ultra-light'        => esc_attr__( 'Ultra-Light 100', 'community-builder' ),
			'ultra-light-italic' => esc_attr__( 'Ultra-Light 100 Italic', 'community-builder' ),
			'light'              => esc_attr__( 'Light 200', 'community-builder' ),
			'light-italic'       => esc_attr__( 'Light 200 Italic', 'community-builder' ),
			'book'               => esc_attr__( 'Book 300', 'community-builder' ),
			'book-italic'        => esc_attr__( 'Book 300 Italic', 'community-builder' ),
			'regular'            => esc_attr__( 'Normal 400', 'community-builder' ),
			'italic'             => esc_attr__( 'Normal 400 Italic', 'community-builder' ),
			'medium'             => esc_attr__( 'Medium 500', 'community-builder' ),
			'medium-italic'      => esc_attr__( 'Medium 500 Italic', 'community-builder' ),
			'semi-bold'          => esc_attr__( 'Semi-Bold 600', 'community-builder' ),
			'semi-bold-italic'   => esc_attr__( 'Semi-Bold 600 Italic', 'community-builder' ),
			'bold'               => esc_attr__( 'Bold 700', 'community-builder' ),
			'bold-italic'        => esc_attr__( 'Bold 700 Italic', 'community-builder' ),
			'extra-bold'         => esc_attr__( 'Extra-Bold 800', 'community-builder' ),
			'extra-bold-italic'  => esc_attr__( 'Extra-Bold 800 Italic', 'community-builder' ),
			'ultra-bold'         => esc_attr__( 'Ultra-Bold 900', 'community-builder' ),
			'ultra-bold-italic'  => esc_attr__( 'Ultra-Bold 900 Italic', 'community-builder' ),
			'invalid-value'      => esc_attr__( 'Invalid Value', 'community-builder' ),
			'back'               => esc_attr__( 'Back', 'community-builder' ),
			'text-align'         => esc_attr__( 'Text Align', 'community-builder' ),
			'text-transform'     => esc_attr__( 'Text Transform', 'community-builder' ),
			'none'               => esc_attr__( 'None', 'community-builder' ),
			'capitalize'         => esc_attr__( 'Capitalize', 'community-builder' ),
			'uppercase'          => esc_attr__( 'Uppercase', 'community-builder' ),
			'lowercase'          => esc_attr__( 'Lowercase', 'community-builder' ),
			'initial'            => esc_attr__( 'Initial', 'community-builder' ),
			'hex-value'          => esc_attr__( 'Hex Value', 'community-builder' ),
		);

		return $translation_strings;
	}
}
