<?php
/**
 * General Panel customize settings.
 *
 * @package    Community_Builder
 * @subpackage Customizer\Panels
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * General panel settings helper.
 */
class CB_Customize_Panel_General {

	/**
	 * Panel id.
	 *
	 * @var string
	 */
	private $panel = 'cb_general';

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_filter( 'cb_customizer_sections', array( $this, 'add_sections' ) );
	}

	/**
	 * Add all sections for this panel.
	 *
	 * @param array $sections sections.
	 *
	 * @return array
	 */
	public function add_sections( $sections ) {

		$new_sections = $this->get_sections();

		return array_merge( $sections, $new_sections );
	}

	/**
	 * Get all sections for this panel.
	 *
	 * @return array
	 */
	public function get_sections() {

		$sections = array();

		$panel = $this->panel;

		$sections['social'] = array(
			'panel'       => $panel,
			'title'       => __( 'Social Profiles', 'community-builder' ),
			'description' => __( 'Enter the complete URL to your profile for each service below that you would like to share. These are used in header/footer social links.', 'community-builder' ),
			'options'     => array(
				'social-facebook'    => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-facebook' ),
					),
					'control' => array(
						'label' => 'Facebook',
						'type'  => 'text',
					),
				),
				'social-twitter'     => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-twitter' ),
					),
					'control' => array(
						'label' => 'Twitter', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-google-plus' => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-google-plus' ),
					),
					'control' => array(
						'label' => 'Google +', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-linkedin'    => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-linkedin' ),
					),
					'control' => array(
						'label' => 'LinkedIn', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-instagram'   => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-instagram' ),
					),
					'control' => array(
						'label' => 'Instagram', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-flickr'      => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-flickr' ),
					),
					'control' => array(
						'label' => 'Flickr', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-youtube'     => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-youtube' ),
					),
					'control' => array(
						'label' => 'YouTube', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-vimeo'       => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-vimeo' ),
					),
					'control' => array(
						'label' => 'Vimeo', // brand names not translated.
						'type'  => 'text',
					),
				),
				'social-pinterest'   => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-pinterest' ),
					),
					'control' => array(
						'label' => 'Pinterest', // brand names not translated.
						'type'  => 'text',
					),
				),

			), // end of options.
		); // end of social section.

		/**
		 * Email
		 */
		$sections['email'] = array(
			'panel'       => $panel,
			'title'       => __( 'Email', 'community-builder' ),
			'description' => __( 'Enter an email address to add an email icon link to your social profile icons.', 'community-builder' ),
			'options'     => array(
				'social-email' => array(
					'setting' => array(
						'sanitize_callback' => 'sanitize_email',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'social-email' ),
					),
					'control' => array(
						'label' => __( 'Email', 'community-builder' ),
						'type'  => 'text',
					),
				),
			),
		);

		/**
		 * RSS
		 */
		$sections['rss'] = array(
			'panel'       => $panel,
			'title'       => __( 'RSS', 'community-builder' ),
			'description' => __( 'If configured, an RSS icon will appear with your social profile icons.', 'community-builder' ),
			'options'     => array(
				'social-rss-heading' => array(
					'control' => array(
						'control_type' => 'CB_Customize_Control_Info_Title',
						'label'        => __( 'Default RSS', 'community-builder' ),
					),
				),
				'hide-rss'           => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'hide-rss' ),
					),
					'control' => array(
						'label' => __( 'Hide default RSS feed link', 'community-builder' ),
						'type'  => 'checkbox',
					),
				),
				'custom-rss'         => array(
					'setting' => array(
						'sanitize_callback' => 'esc_url_raw',
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'custom-rss' ),
					),
					'control' => array(
						'label' => __( 'Custom RSS URL (replaces default)', 'community-builder' ),
						'type'  => 'text',
					),
				),
			),
		);

		return apply_filters( 'cb_customizer_general_sections', $sections );
	}

} // end of class.

new CB_Customize_Panel_General();
